Title: [265753] trunk
Revision
265753
Author
[email protected]
Date
2020-08-17 05:41:09 -0700 (Mon, 17 Aug 2020)

Log Message

[GTK][WPE] Remove support for NPAPI plugins
https://bugs.webkit.org/show_bug.cgi?id=215503

Reviewed by Darin Adler.

.:

* Source/cmake/OptionsGTK.cmake:

Source/WebKit:

* PlatformGTK.cmake:
* PluginProcess/unix/PluginControllerProxyUnix.cpp: Removed.
* PluginProcess/unix/PluginProcessMainUnix.cpp: Removed.
* PluginProcess/unix/PluginProcessUnix.cpp: Removed.
* Shared/Plugins/Netscape/unix/NetscapePluginModuleUnix.cpp: Removed.
* Shared/Plugins/unix/PluginSearchPath.cpp: Removed.
* Shared/Plugins/unix/PluginSearchPath.h: Removed.
* SourcesGTK.txt:
* SourcesWPE.txt:
* UIProcess/API/glib/WebKitMimeInfo.cpp:
(webkit_mime_info_ref):
(webkit_mime_info_unref):
(webkit_mime_info_get_mime_type):
(webkit_mime_info_get_description):
(webkit_mime_info_get_extensions):
* UIProcess/API/glib/WebKitMimeInfoPrivate.h: Removed.
* UIProcess/API/glib/WebKitPlugin.cpp:
(webkit_plugin_get_name):
(webkit_plugin_get_description):
(webkit_plugin_get_path):
(webkit_plugin_get_mime_info_list):
* UIProcess/API/glib/WebKitPluginPrivate.h: Removed.
* UIProcess/API/glib/WebKitSettings.cpp:
(webKitSettingsSetProperty):
(webKitSettingsGetProperty):
(webkit_settings_class_init):
(webkit_settings_get_enable_plugins):
(webkit_settings_set_enable_plugins):
* UIProcess/API/glib/WebKitWebContext.cpp:
(webkit_web_context_set_additional_plugins_directory):
(webkit_web_context_get_plugins):
(webkit_web_context_get_plugins_finish):
* UIProcess/API/glib/WebKitWebView.cpp:
(webkitWebViewLoadFail):
* UIProcess/API/glib/WebKitWebsiteData.cpp:
(recordContainsSupportedDataTypes):
(toWebKitWebsiteDataTypes):
* UIProcess/API/glib/WebKitWebsiteDataManager.cpp:
(toWebsiteDataTypes):
* UIProcess/API/gtk/WebKitError.h:
* UIProcess/API/gtk/WebKitMimeInfo.h:
* UIProcess/API/gtk/WebKitPlugin.h:
* UIProcess/API/gtk/WebKitSettings.h:
* UIProcess/API/gtk/WebKitWebContext.h:
* UIProcess/API/gtk/WebKitWebsiteData.h:
* UIProcess/API/wpe/WebKitError.h:
* UIProcess/API/wpe/WebKitMimeInfo.h:
* UIProcess/API/wpe/WebKitPlugin.h:
* UIProcess/API/wpe/WebKitSettings.h:
* UIProcess/API/wpe/WebKitWebContext.h:
* UIProcess/API/wpe/WebKitWebsiteData.h:
* UIProcess/Launcher/glib/BubblewrapLauncher.cpp:
(WebKit::bubblewrapSpawn):
* UIProcess/Launcher/glib/ProcessLauncherGLib.cpp:
(WebKit::ProcessLauncher::launchProcess):
* UIProcess/Plugins/gtk/PluginInfoCache.cpp: Removed.
* UIProcess/Plugins/gtk/PluginInfoCache.h: Removed.
* UIProcess/Plugins/unix/PluginInfoStoreUnix.cpp: Removed.
* UIProcess/Plugins/unix/PluginProcessProxyUnix.cpp: Removed.
* UIProcess/WebPageProxy.h:
* UIProcess/WebPageProxy.messages.in:
* UIProcess/gtk/WebPageProxyGtk.cpp:
* WebProcess/Plugins/Netscape/unix/NetscapePluginUnix.cpp: Removed.
* WebProcess/Plugins/Netscape/unix/NetscapePluginUnix.h: Removed.
* WebProcess/Plugins/Netscape/unix/PluginProxyUnix.cpp: Removed.
* WebProcess/Plugins/Netscape/x11/NetscapePluginX11.cpp: Removed.
* WebProcess/Plugins/Netscape/x11/NetscapePluginX11.h: Removed.
* WebProcess/Plugins/PluginController.h:
* WebProcess/Plugins/PluginView.cpp:
* WebProcess/Plugins/PluginView.h:

Tools:

* PlatformGTK.cmake:
* TestWebKitAPI/Tests/WebKitGLib/TestWebKitSettings.cpp:
(testWebKitSettings):
* TestWebKitAPI/Tests/WebKitGLib/TestWebKitWebContext.cpp:
(beforeAll):

LayoutTests:

Skip tests using plugins and remove expectations.

* platform/glib/TestExpectations:
* platform/gtk/TestExpectations:
* platform/gtk/accessibility/plugin-expected.txt: Removed.
* platform/gtk/http/tests/plugins/plugin-_javascript_-access-allow-all-plugins-expected.txt: Removed.
* platform/gtk/plugins/document-open-expected.txt: Removed.
* platform/gtk/plugins/embed-attributes-style-expected.png: Removed.
* platform/gtk/plugins/embed-attributes-style-expected.txt: Removed.
* platform/gtk/plugins/iframe-plugin-bgcolor-expected.png: Removed.
* platform/gtk/plugins/invalidate-rect-with-null-npp-argument-expected.txt: Removed.
* platform/gtk/plugins/invalidate-rect-with-null-npp-argument.html: Removed.
* platform/gtk/plugins/mouse-click-plugin-clears-selection-expected.png: Removed.
* platform/gtk/plugins/mouse-click-plugin-clears-selection-expected.txt: Removed.
* platform/gtk/plugins/nested-plugin-objects-expected.txt: Removed.
* platform/gtk/plugins/netscape-destroy-plugin-script-objects-expected.txt: Removed.
* platform/gtk/plugins/netscape-dom-access-expected.png: Removed.
* platform/gtk/plugins/netscape-dom-access-expected.txt: Removed.
* platform/gtk/plugins/npruntime/object-from-destroyed-plugin-expected.txt: Removed.
* platform/gtk/plugins/npruntime/object-from-destroyed-plugin-in-subframe-expected.txt: Removed.
* platform/gtk/plugins/plugin-clip-subframe-expected.txt: Removed.
* platform/gtk/plugins/plugin-initiate-popup-window-expected.txt: Removed.
* platform/gtk/plugins/plugin-_javascript_-access-expected.txt: Removed.
* platform/gtk/plugins/resize-from-plugin-expected.txt: Removed.
* platform/wpe/TestExpectations:

Modified Paths

Removed Paths

Diff

Modified: trunk/ChangeLog (265752 => 265753)


--- trunk/ChangeLog	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/ChangeLog	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,3 +1,12 @@
+2020-08-17  Carlos Garcia Campos  <[email protected]>
+
+        [GTK][WPE] Remove support for NPAPI plugins
+        https://bugs.webkit.org/show_bug.cgi?id=215503
+
+        Reviewed by Darin Adler.
+
+        * Source/cmake/OptionsGTK.cmake:
+
 2020-08-12  Keith Rollin  <[email protected]>
 
         Remove the need for defining USE_NEW_BUILD_SYSTEM

Modified: trunk/LayoutTests/ChangeLog (265752 => 265753)


--- trunk/LayoutTests/ChangeLog	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/LayoutTests/ChangeLog	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,3 +1,36 @@
+2020-08-17  Carlos Garcia Campos  <[email protected]>
+
+        [GTK][WPE] Remove support for NPAPI plugins
+        https://bugs.webkit.org/show_bug.cgi?id=215503
+
+        Reviewed by Darin Adler.
+
+        Skip tests using plugins and remove expectations.
+
+        * platform/glib/TestExpectations:
+        * platform/gtk/TestExpectations:
+        * platform/gtk/accessibility/plugin-expected.txt: Removed.
+        * platform/gtk/http/tests/plugins/plugin-_javascript_-access-allow-all-plugins-expected.txt: Removed.
+        * platform/gtk/plugins/document-open-expected.txt: Removed.
+        * platform/gtk/plugins/embed-attributes-style-expected.png: Removed.
+        * platform/gtk/plugins/embed-attributes-style-expected.txt: Removed.
+        * platform/gtk/plugins/iframe-plugin-bgcolor-expected.png: Removed.
+        * platform/gtk/plugins/invalidate-rect-with-null-npp-argument-expected.txt: Removed.
+        * platform/gtk/plugins/invalidate-rect-with-null-npp-argument.html: Removed.
+        * platform/gtk/plugins/mouse-click-plugin-clears-selection-expected.png: Removed.
+        * platform/gtk/plugins/mouse-click-plugin-clears-selection-expected.txt: Removed.
+        * platform/gtk/plugins/nested-plugin-objects-expected.txt: Removed.
+        * platform/gtk/plugins/netscape-destroy-plugin-script-objects-expected.txt: Removed.
+        * platform/gtk/plugins/netscape-dom-access-expected.png: Removed.
+        * platform/gtk/plugins/netscape-dom-access-expected.txt: Removed.
+        * platform/gtk/plugins/npruntime/object-from-destroyed-plugin-expected.txt: Removed.
+        * platform/gtk/plugins/npruntime/object-from-destroyed-plugin-in-subframe-expected.txt: Removed.
+        * platform/gtk/plugins/plugin-clip-subframe-expected.txt: Removed.
+        * platform/gtk/plugins/plugin-initiate-popup-window-expected.txt: Removed.
+        * platform/gtk/plugins/plugin-_javascript_-access-expected.txt: Removed.
+        * platform/gtk/plugins/resize-from-plugin-expected.txt: Removed.
+        * platform/wpe/TestExpectations:
+
 2020-08-17  Yusuke Suzuki  <[email protected]>
 
         JSDOMConstructorNotConstructable should be a constructor

Modified: trunk/LayoutTests/platform/glib/TestExpectations (265752 => 265753)


--- trunk/LayoutTests/platform/glib/TestExpectations	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/LayoutTests/platform/glib/TestExpectations	2020-08-17 12:41:09 UTC (rev 265753)
@@ -72,8 +72,6 @@
 webkit.org/b/153292 accessibility/text-marker [ Skip ]
 webkit.org/b/141072 accessibility/frame-disconnect-textmarker-cache-crash.html [ Skip ]
 
-webkit.org/b/143468 accessibility/plugin.html [ Failure ]
-
 webkit.org/b/182107 accessibility/aria-combobox-control-owns-elements.html [ Timeout ]
 
 webkit.org/b/98363 accessibility/canvas-fallback-content-2.html [ Failure ]
@@ -958,6 +956,76 @@
 # Payment Request
 imported/w3c/web-platform-tests/payment-request [ Skip ]
 
+# Plugins
+plugins/ [ Skip ]
+http/tests/plugins [ Skip ]
+http/tests/contentextensions/plugin-doesnt-crash.html [ Skip ]
+http/tests/security/cross-origin-plugin.html [ Skip ]
+http/tests/security/cross-origin-plugin-allowed.html [ Skip ]
+http/tests/security/cross-origin-plugin-private-browsing-toggled.html [ Skip ]
+http/tests/security/cross-origin-plugin-private-browsing-toggled-allowed.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-affects-child.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-invalid.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-mismatched-data.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-mismatched-url.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-notype-data.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-notype-url.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-nourl-allowed.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-nourl-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-url-01.html [ Skip ]
+http/tests/security/contentSecurityPolicy/1.1/plugintypes-url-02.html [ Skip ]
+http/tests/security/contentSecurityPolicy/block-all-mixed-content/resources/frame-with-insecure-plugin.html [ Skip ]
+http/tests/security/contentSecurityPolicy/embed-with-no-url-allowed-by-default-src-star.html [ Skip ]
+http/tests/security/contentSecurityPolicy/embed-with-no-url-allowed-by-star.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-does-not-affect-child.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-no-url-allowed.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-no-url-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-none-allowed.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-none-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-param-code-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-param-movie-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-param-src-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-src-param-url-blocked.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-with-no-url-allowed-by-default-src-star.html [ Skip ]
+http/tests/security/contentSecurityPolicy/object-with-no-url-allowed-by-star.html [ Skip ]
+http/tests/security/contentSecurityPolicy/plugin-blocked-in-about-blank-window.html [ Skip ]
+http/tests/security/contentSecurityPolicy/source-list-parsing-no-semicolon.html [ Skip ]
+http/tests/security/contentSecurityPolicy/userAgentShadowDOM/allow-embed-plugin.html [ Skip ]
+http/tests/security/contentSecurityPolicy/userAgentShadowDOM/allow-object-plugin.html [ Skip ]
+http/tests/security/storage-blocking-loosened-plugin.html [ Skip ]
+http/tests/security/storage-blocking-loosened-private-browsing-plugin.html [ Skip ]
+http/tests/security/storage-blocking-strengthened-plugin.html [ Skip ]
+http/tests/security/storage-blocking-strengthened-private-browsing-plugin.html [ Skip ]
+compositing/plugins [ Skip ]
+compositing/geometry/empty-embed-rects.html [ Skip ]
+accessibility/plugin.html [ Skip ]
+editing/selection/selection-plugin-clear-crash.html [ Skip ]
+fast/frames/iframe-plugin-load-remove-document-crash.html [ Skip ]
+fast/history/go-back-to-iframe-with-plugin.html [ Skip ]
+fast/images/embed-does-not-propagate-dimensions-to-object-ancestor.html [ Skip ]
+fast/layers/clip-rects-transformed-2.html [ Skip ]
+fast/layers/clip-rects-transformed.html [ Skip ]
+fast/loader/loadInProgress.html [ Skip ]
+fast/loader/reload-zero-byte-plugin.html [ Skip ]
+fast/replaced/border-radius-clip.html [ Skip ]
+fast/replaced/embed-display-none.html [ Skip ]
+fast/replaced/invalid-object-with-fallback.html [ Skip ]
+fast/replaced/no-focus-ring-embed.html [ Skip ]
+fast/replaced/no-focus-ring-object.html [ Skip ]
+fast/replaced/object-with-non-empty-classid-triggers-fallback.html [ Skip ]
+fullscreen/full-screen-plugin.html [ Skip ]
+imported/blink/http/tests/plugins [ Skip ]
+imported/blink/plugins [ Skip ]
+js/dom/reflect-set-onto-dom.html [ Skip ]
+security/contentSecurityPolicy/object-src-none-blocks-quicktime-plugin-replacement.html [ Skip ]
+security/contentSecurityPolicy/object-src-none-blocks-youtube-plugin-replacement.html [ Skip ]
+security/contentSecurityPolicy/plugins-types-allows-quicktime-plugin-replacement.html [ Skip ]
+security/contentSecurityPolicy/plugins-types-allows-youtube-plugin-replacement.html [ Skip ]
+security/contentSecurityPolicy/plugins-types-blocks-quicktime-plugin-replacement-without-mime-type.html [ Skip ]
+security/contentSecurityPolicy/plugins-types-blocks-quicktime-plugin-replacement.html [ Skip ]
+security/contentSecurityPolicy/plugins-types-blocks-youtube-plugin-replacement-without-mime-type.html [ Skip ]
+security/contentSecurityPolicy/plugins-types-blocks-youtube-plugin-replacement.html [ Skip ]
+
 # WebArchive
 webarchive [ WontFix ]
 http/tests/webarchive [ WontFix ]

Modified: trunk/LayoutTests/platform/gtk/TestExpectations (265752 => 265753)


--- trunk/LayoutTests/platform/gtk/TestExpectations	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/LayoutTests/platform/gtk/TestExpectations	2020-08-17 12:41:09 UTC (rev 265753)
@@ -345,8 +345,6 @@
 webkit.org/b/169918 compositing/overflow/overflow-auto-with-touch-toggle.html [ Failure ]
 webkit.org/b/169918 compositing/overflow/scrolling-without-painting.html [ Failure ]
 webkit.org/b/169918 compositing/overflow/updating-scrolling-content.html [ Failure ]
-webkit.org/b/169918 compositing/plugins/no-backing-store.html [ Failure ]
-webkit.org/b/169918 compositing/plugins/small-to-large-composited-plugin.html [ Failure ]
 webkit.org/b/169918 compositing/repaint/invalidations-on-composited-layers.html [ Failure ]
 webkit.org/b/169918 compositing/repaint/positioned-movement.html [ Failure ]
 webkit.org/b/169918 compositing/repaint/resize-repaint.html [ Failure ]
@@ -401,7 +399,6 @@
 webkit.org/b/169918 compositing/visibility/visibility-composited.html [ Missing Failure ]
 webkit.org/b/169918 compositing/webgl/webgl-no-alpha.html [ Missing Failure ]
 webkit.org/b/169918 compositing/webgl/webgl-reflection.html [ Missing Failure ]
-webkit.org/b/169918 compositing/plugins/composited-plugin.html [ Missing Failure ]
 webkit.org/b/169918 compositing/fixed-with-fixed-layout.html [ Crash ]
 webkit.org/b/169918 compositing/video/video-background-color.html [ Crash Pass ]
 webkit.org/b/214868 compositing/clipping/border-radius-stacking-context-clip.html [ ImageOnlyFailure ]
@@ -568,9 +565,6 @@
 # DataCue.value not enabled
 Bug(GTK) http/tests/media/track-in-band-hls-metadata.html [ Skip ]
 
-# Snapshotted plugins not enabled
-webkit.org/b/98696 plugins/snapshotting [ Skip ]
-
 # Missing WebSpeech implementation
 webkit.org/b/136224 fast/speechsynthesis [ Skip ]
 
@@ -610,9 +604,6 @@
 editing/inserting/smart-quote-with-all-configurations.html [ Skip ]
 fast/events/input-event-insert-link.html [ Skip ]
 
-# QuickTime plug-in not relevant to this port
-Bug(GTK) plugins/quicktime-plugin-replacement.html [ Skip ]
-
 # ENABLE(CSS_SCROLL_SNAP) is disabled.
 css3/scroll-snap [ Skip ]
 
@@ -856,16 +847,6 @@
 webkit.org/b/160120 fast/text/emoji-single-parent-family.html [ Skip ]
 webkit.org/b/160120 editing/caret/emoji.html [ Skip ]
 
-# No support for QuickTime/YouTube plugin replacement.
-security/contentSecurityPolicy/object-src-none-blocks-quicktime-plugin-replacement.html [ Skip ]
-security/contentSecurityPolicy/object-src-none-blocks-youtube-plugin-replacement.html [ Skip ]
-security/contentSecurityPolicy/plugins-types-allows-quicktime-plugin-replacement.html [ Skip ]
-security/contentSecurityPolicy/plugins-types-allows-youtube-plugin-replacement.html [ Skip ]
-security/contentSecurityPolicy/plugins-types-blocks-quicktime-plugin-replacement-without-mime-type.html [ Skip ]
-security/contentSecurityPolicy/plugins-types-blocks-quicktime-plugin-replacement.html [ Skip ]
-security/contentSecurityPolicy/plugins-types-blocks-youtube-plugin-replacement-without-mime-type.html [ Skip ]
-security/contentSecurityPolicy/plugins-types-blocks-youtube-plugin-replacement.html [ Skip ]
-
 # No support for descriptive audio tracks in HLS file
 http/tests/media/hls/hls-accessiblity-describes-video-menu.html [ Skip ]
 http/tests/media/hls/hls-accessiblity-describes-video.html [ Skip ]
@@ -899,9 +880,6 @@
 
 webkit.org/b/168433 http/tests/xmlhttprequest/redirections-and-user-headers.html [ Failure ]
 
-# WebKit2 plug-ins: No support for getting the form value.
-plugins/form-value.html [ Skip ]
-
 # Require FILE_REPLACEMENT.
 fast/files/filereader-zip-bundle-using-open-panel.html [ Skip ]
 http/tests/local/fileapi/upload-zip-bundle-as-blob-using-open-panel.html [ Skip ]
@@ -971,9 +949,6 @@
 # Requires support for testing text replacement
 editing/spelling/text-replacement-after-typing-to-word.html [ Skip ]
 
-# Depends on mac-specific code in TestController.
-webkit.org/b/187550 http/tests/plugins/plugin-allow-then-reload.html [ Failure ]
-
 # MediaRecorder is not currently implemented
 http/wpt/mediarecorder [ Skip ]
 imported/w3c/web-platform-tests/mediacapture-record [ Skip ]
@@ -1222,14 +1197,8 @@
 
 webkit.org/b/90957 [ Release ] js/dom/random-array-gc-stress.html [ Timeout Crash Pass ]
 
-webkit.org/b/105689 [ Debug ] plugins/npruntime/embed-property-iframe-equality.html [ Crash ]
-
 webkit.org/b/120200 [ Debug ] http/tests/security/XFrameOptions/x-frame-options-allowall.html [ Crash Pass ]
 
-Bug(GTK) plugins/document-open.html [ Crash Timeout ]
-
-webkit.org/b/82020 plugins/netscape-dom-access-and-reload.html [ Failure Crash Pass ]
-
 webkit.org/b/163826 storage/domstorage/events/basic-body-attribute.html [ Failure Pass ]
 
 webkit.org/b/152642 http/tests/misc/detached-frame-console.html [ Crash Pass Timeout Failure ]
@@ -1305,8 +1274,6 @@
 webkit.org/b/122481 svg/animations/svglengthlist-animation-3.html [ Failure Pass ]
 webkit.org/b/62204 svg/custom/circular-marker-reference-4.svg [ Failure Pass ]
 
-webkit.org/b/119735 [ Debug ] plugins/unavailable-plugin-indicator-obscurity.html [ Skip ]
-
 webkit.org/b/71777 fast/lists/inlineBoxWrapperNullCheck.html [ Failure Pass ]
 
 webkit.org/b/80129 fast/frames/flattening/iframe-flattening-fixed-width.html [ Failure Pass ]
@@ -1370,8 +1337,6 @@
 
 webkit.org/b/124511 media/video-played-reset.html [ Failure Pass Crash ]
 
-webkit.org/b/125407 plugins/plugin-clip-subframe.html [ Failure Pass ]
-
 webkit.org/b/126420 fast/table/dynamic-caption-add-before-child.xhtml [ Failure Pass ]
 
 webkit.org/b/126432 fast/css/acid2-pixel.html [ Failure Pass ]
@@ -1438,8 +1403,6 @@
 webkit.org/b/134576 media/track/video/video-track-mkv-theora-selected.html [ Failure Timeout Pass Crash ]
 webkit.org/b/134576 webkit.org/b/198830 media/track/video/video-track-mkv-theora-language.html [ Failure Timeout Pass Crash ]
 
-webkit.org/b/134760 plugins/layout-in-beforeload-listener-affects-plugin-loading.html [ Failure Pass ]
-
 webkit.org/b/135583 http/tests/media/video-play-progress.html [ Crash Timeout Pass ]
 
 webkit.org/b/136066 animations/fill-mode-iteration-count-non-integer.html [ Timeout Pass ]
@@ -1471,9 +1434,6 @@
 
 webkit.org/b/153771 animations/resume-after-page-cache.html [ Timeout Failure Pass ]
 
-webkit.org/b/153942 plugins/private-browsing-mode-2.html [ Failure Pass ]
-webkit.org/b/153942 plugins/private-browsing-mode.html [ Failure Pass ]
-
 webkit.org/b/153943 webaudio/convolution-mono-mono.html [ Failure Pass ]
 
 webkit.org/b/156436 fast/harness/sample-fail-mismatch-reftest.html [ ImageOnlyFailure Pass ]
@@ -1505,10 +1465,6 @@
 webkit.org/b/153941 fast/text/control-characters/visible-control-characters-3.html [ ImageOnlyFailure Pass ]
 webkit.org/b/153941 fast/text/control-characters/visible-control-characters-3.xhtml [ ImageOnlyFailure Pass ]
 
-webkit.org/b/160136 http/tests/security/cross-origin-plugin-private-browsing-toggled-allowed.html [ Failure Pass ]
-
-webkit.org/b/163532 plugins/js-from-destroy.html [ Failure Pass ]
-
 webkit.org/b/168780 fast/forms/input-first-letter-edit.html [ ImageOnlyFailure Pass ]
 
 webkit.org/b/116277 webkit.org/b/198830 media/video-buffered.html [ Pass Failure Crash ]
@@ -1614,8 +1570,6 @@
 
 webkit.org/b/187590 imported/w3c/web-platform-tests/web-animations/timing-model/timelines/document-timelines.html [ Failure Pass ]
 
-webkit.org/b/187761 http/tests/security/contentSecurityPolicy/1.1/plugintypes-affects-child.html [ Pass Failure ]
-
 webkit.org/b/187760 fast/mediastream/get-user-media-on-loadedmetadata.html [ Pass Failure ]
 
 webkit.org/b/168357 http/wpt/resource-timing/rt-initiatorType-media.html [ Pass Failure ]
@@ -1642,8 +1596,6 @@
 
 webkit.org/b/191685 http/wpt/css/css-animations/set-animation-play-state-to-paused-001.html [ ImageOnlyFailure Pass Timeout ]
 
-webkit.org/b/191687 imported/blink/http/tests/plugins/get-url-notify-on-removal.html [ Timeout Pass ]
-
 webkit.org/b/192149 imported/blink/animations/animation-events-prefixed-01.html [ Timeout Pass ]
 
 webkit.org/b/192903 imported/w3c/web-platform-tests/service-workers/service-worker/fetch-request-redirect.https.html [ Pass Failure ]
@@ -2289,8 +2241,6 @@
 
 webkit.org/b/147518 inspector/debugger/nested-inspectors.html [ Timeout ]
 
-Bug(GTK) plugins/reloadplugins-and-pages.html [ Timeout ]
-
 webkit.org/b/135053 html5lib/webkit-resumer.html [ Timeout Pass ]
 
 webkit.org/b/135086 media/video-seek-with-negative-playback.html [ Timeout Pass ]
@@ -2404,8 +2354,6 @@
 webkit.org/b/202736 http/tests/appcache/remove-cache.html [ Failure ]
 webkit.org/b/202736 [ Release ] http/wpt/cache-storage/quota-third-party.https.html [ Failure Pass Timeout ]
 
-webkit.org/b/206876 http/tests/security/storage-blocking-strengthened-private-browsing-plugin.html [ Timeout ]
-
 webkit.org/b/207711 fast/history/page-cache-webdatabase-pending-transaction.html [ Pass Timeout ]
 webkit.org/b/207711 [ Debug ] imported/w3c/web-platform-tests/css/mediaqueries/test_media_queries.html [ Timeout ]
 webkit.org/b/207711 [ Debug ] fast/selectors/slow-style-sharing-with-long-cousin-list.html [ Timeout ]
@@ -2541,8 +2489,6 @@
 webkit.org/b/157179 fast/forms/range/slider-delete-while-dragging-thumb.html [ Failure ]
 webkit.org/b/157179 fast/lists/drag-into-marker.html [ Failure ]
 webkit.org/b/157179 http/tests/security/resources/drag-drop-allowed.html [ Skip ]
-webkit.org/b/157179 plugins/mouse-events-fixedpos.html [ Failure ]
-webkit.org/b/157179 plugins/mouse-events.html [ Failure Timeout ]
 webkit.org/b/157179 editing/pasteboard/cleanup-on-move.html [ Failure ]
 webkit.org/b/157179 editing/pasteboard/drag-list-item.html [ Failure ]
 webkit.org/b/157179 fast/events/ondragenter.html [ Failure ]
@@ -2579,10 +2525,6 @@
 Bug(GTK) svg/text/select-x-list-1.svg [ Failure Pass ]
 Bug(GTK) svg/text/select-x-list-with-tspans-1.svg [ Failure Pass ]
 
-# [Qt][WK2] New http/tests/security/cross-origin-plugin* tests fail
-# https://bugs.webkit.org/show_bug.cgi?id=95935
-webkit.org/b/95935 http/tests/security/cross-origin-plugin.html [ Failure ]
-
 # Missing support for the modifierArray argument to EventSendingController::mouseMoveTo().
 Bug(GTK) platform/gtk/fast/events/event-sender-metakey.html [ Failure ]
 
@@ -2613,13 +2555,6 @@
 Bug(GTK) fast/writing-mode/Kusa-Makura-background-canvas.html [ Failure Timeout Pass ]
 Bug(GTK) http/tests/security/cross-origin-xsl-BLOCKED.html [ Failure ]
 Bug(GTK) http/tests/security/cross-origin-xsl-redirect-BLOCKED.html [ Failure ]
-Bug(GTK) http/tests/security/storage-blocking-strengthened-plugin.html [ Failure ]
-Bug(GTK) plugins/keyboard-events.html [ Failure ]
-Bug(GTK) plugins/netscape-plugin-setwindow-size-2.html [ Failure ]
-Bug(GTK) plugins/npp-set-window-called-during-destruction.html [ Failure ]
-Bug(GTK) plugins/npruntime/browser-object-identity.html [ Failure ]
-Bug(GTK) plugins/npruntime/embed-property-equality.html [ Failure ]
-Bug(GTK) plugins/resize-from-plugin.html [ Failure ]
 
 # Selection doesn't work properly.
 Bug(GTK) editing/selection/context-menu-text-selection-lookup.html [ Failure Pass ]
@@ -2663,9 +2598,6 @@
 
 Bug(GTK) http/tests/misc/acid3.html [ Failure ]
 
-# eventSender.keyDown call does not get executed from the TestNetscapePlugin
-webkit.org/b/90383 http/tests/plugins/plugin-document-has-focus.html [ Skip ]
-
 webkit.org/b/30620 fast/xsl/sort-locale.xml [ Failure ]
 
 webkit.org/b/53986 svg/text/caret-in-svg-text.xhtml [ Failure ]
@@ -2749,12 +2681,6 @@
 # Started failing after it was added in r116473
 webkit.org/b/85969 http/tests/loading/post-in-iframe-with-back-navigation.html [ Failure ]
 
-webkit.org/b/86443 plugins/npruntime/delete-plugin-within-hasProperty-return-false.html [ Failure ]
-webkit.org/b/86443 plugins/npruntime/delete-plugin-within-hasProperty-return-true.html [ Failure ]
-webkit.org/b/86443 plugins/npruntime/delete-plugin-within-setProperty.html [ Failure ]
-
-webkit.org/b/51027 [ Release ] plugins/refcount-leaks.html [ Failure ]
-
 # Failing after r121121 on both GTK and EFL
 webkit.org/b/89845 fast/forms/input-set-composition-scroll.html [ Failure ]
 
@@ -2885,12 +2811,6 @@
 
 webkit.org/b/132914 http/tests/security/drag-drop-local-file.html [ Failure ]
 
-webkit.org/b/132919 platform/gtk/plugins/invalidate-rect-with-null-npp-argument.html [ Failure ]
-
-webkit.org/b/132921 plugins/evaluate-js-after-removing-plugin-element.html [ Failure ]
-
-webkit.org/b/132923 http/tests/security/cross-origin-plugin-private-browsing-toggled.html [ Pass Failure ]
-
 webkit.org/b/133146 fast/sub-pixel/inline-block-with-padding.html [ Failure ]
 
 webkit.org/b/133803 editing/deleting/delete-by-word-001.html [ Failure ]
@@ -3226,8 +3146,6 @@
 
 webkit.org/b/182765 fast/text/emphasis-overlap.html [ Failure ImageOnlyFailure ]
 
-webkit.org/b/183033 http/tests/plugins/supported-plugin-origin-specific-visibility.html [ Failure ]
-
 webkit.org/b/198830 media/context-menu-actions.html [ Pass Crash ]
 
 webkit.org/b/183902 fast/dom/frame-loading-via-document-write.html [ Failure ]

Deleted: trunk/LayoutTests/platform/gtk/accessibility/plugin-expected.txt (265752 => 265753)


--- trunk/LayoutTests/platform/gtk/accessibility/plugin-expected.txt	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/LayoutTests/platform/gtk/accessibility/plugin-expected.txt	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,23 +0,0 @@
- 
-AXRole: AXGroup
-AXParent: AXWebArea
-AXChildren: 0
-AXPosition: { 8.000000, 8.000000 }
-AXSize: { 784.000000, 150.000000 }
-AXTitle: 
-AXDescription: 
-AXValue: <obj>
-AXFocusable: 0
-AXFocused: 0
-AXSelectable: 0
-AXSelected: 0
-AXMultiSelectable: 0
-AXEnabled: 1
-AXExpanded: 0
-AXRequired: 0
-AXChecked: 0
-AXPlatformAttributes: toolkit:WebKitGtk
-------------
-
-
-

Modified: trunk/LayoutTests/platform/wpe/TestExpectations (265752 => 265753)


--- trunk/LayoutTests/platform/wpe/TestExpectations	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/LayoutTests/platform/wpe/TestExpectations	2020-08-17 12:41:09 UTC (rev 265753)
@@ -680,11 +680,6 @@
 webkit.org/b/213131 inspector/ [ Skip ]
 webkit.org/b/213131 media/ [ Skip ]
 
-plugins/ [ Skip ]
-http/tests/plugins [ Skip ]
-imported/blink/http/tests/plugins/get-url-notify-on-removal.html [ Skip ]
-imported/blink/plugins/empty-per-context-data.html [ Skip ]
-
 Bug(WPE) fast/autoresize [ Skip ]
 webkit.org/b/213131 fast/files [ Skip ]
 webkit.org/b/213131 fast/forms [ Skip ]
@@ -1341,8 +1336,6 @@
 Bug(WPE) security/contentSecurityPolicy/image-with-blob-url-allowed-by-img-src-star-with-AllowContentSecurityPolicySourceStarToMatchAnyProtocol-enabled.html [ Skip ]
 Bug(WPE) security/contentSecurityPolicy/image-with-blob-url-blocked-by-img-src-star.html [ Skip ]
 Bug(WPE) security/contentSecurityPolicy/video-with-blob-url-allowed-by-media-src-star.html [ Skip ]
-# Require QuickTime support
-Bug(WPE) security/contentSecurityPolicy/plugins-types-allows-quicktime-plugin-replacement.html [ Skip ]
 
 # accessibility/
 webkit.org/b/68512 accessibility/aria-hidden-updates-alldescendants.html [ Failure ]
@@ -1653,7 +1646,6 @@
 # This 3 fullscreen tests are still not passing.
 webkit.org/b/185676 fullscreen/requestFullscreen-escape-key.html [ Failure ]
 webkit.org/b/185676 fullscreen/video-controls-rtl.html [ Failure ]
-webkit.org/b/185676 fullscreen/full-screen-plugin.html [ Timeout ]
 
 webkit.org/b/185254 http/tests/cache/disk-cache/redirect-chain-limits.html [ Failure ]
 

Modified: trunk/Source/WebKit/ChangeLog (265752 => 265753)


--- trunk/Source/WebKit/ChangeLog	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/ChangeLog	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,3 +1,81 @@
+2020-08-17  Carlos Garcia Campos  <[email protected]>
+
+        [GTK][WPE] Remove support for NPAPI plugins
+        https://bugs.webkit.org/show_bug.cgi?id=215503
+
+        Reviewed by Darin Adler.
+
+        * PlatformGTK.cmake:
+        * PluginProcess/unix/PluginControllerProxyUnix.cpp: Removed.
+        * PluginProcess/unix/PluginProcessMainUnix.cpp: Removed.
+        * PluginProcess/unix/PluginProcessUnix.cpp: Removed.
+        * Shared/Plugins/Netscape/unix/NetscapePluginModuleUnix.cpp: Removed.
+        * Shared/Plugins/unix/PluginSearchPath.cpp: Removed.
+        * Shared/Plugins/unix/PluginSearchPath.h: Removed.
+        * SourcesGTK.txt:
+        * SourcesWPE.txt:
+        * UIProcess/API/glib/WebKitMimeInfo.cpp:
+        (webkit_mime_info_ref):
+        (webkit_mime_info_unref):
+        (webkit_mime_info_get_mime_type):
+        (webkit_mime_info_get_description):
+        (webkit_mime_info_get_extensions):
+        * UIProcess/API/glib/WebKitMimeInfoPrivate.h: Removed.
+        * UIProcess/API/glib/WebKitPlugin.cpp:
+        (webkit_plugin_get_name):
+        (webkit_plugin_get_description):
+        (webkit_plugin_get_path):
+        (webkit_plugin_get_mime_info_list):
+        * UIProcess/API/glib/WebKitPluginPrivate.h: Removed.
+        * UIProcess/API/glib/WebKitSettings.cpp:
+        (webKitSettingsSetProperty):
+        (webKitSettingsGetProperty):
+        (webkit_settings_class_init):
+        (webkit_settings_get_enable_plugins):
+        (webkit_settings_set_enable_plugins):
+        * UIProcess/API/glib/WebKitWebContext.cpp:
+        (webkit_web_context_set_additional_plugins_directory):
+        (webkit_web_context_get_plugins):
+        (webkit_web_context_get_plugins_finish):
+        * UIProcess/API/glib/WebKitWebView.cpp:
+        (webkitWebViewLoadFail):
+        * UIProcess/API/glib/WebKitWebsiteData.cpp:
+        (recordContainsSupportedDataTypes):
+        (toWebKitWebsiteDataTypes):
+        * UIProcess/API/glib/WebKitWebsiteDataManager.cpp:
+        (toWebsiteDataTypes):
+        * UIProcess/API/gtk/WebKitError.h:
+        * UIProcess/API/gtk/WebKitMimeInfo.h:
+        * UIProcess/API/gtk/WebKitPlugin.h:
+        * UIProcess/API/gtk/WebKitSettings.h:
+        * UIProcess/API/gtk/WebKitWebContext.h:
+        * UIProcess/API/gtk/WebKitWebsiteData.h:
+        * UIProcess/API/wpe/WebKitError.h:
+        * UIProcess/API/wpe/WebKitMimeInfo.h:
+        * UIProcess/API/wpe/WebKitPlugin.h:
+        * UIProcess/API/wpe/WebKitSettings.h:
+        * UIProcess/API/wpe/WebKitWebContext.h:
+        * UIProcess/API/wpe/WebKitWebsiteData.h:
+        * UIProcess/Launcher/glib/BubblewrapLauncher.cpp:
+        (WebKit::bubblewrapSpawn):
+        * UIProcess/Launcher/glib/ProcessLauncherGLib.cpp:
+        (WebKit::ProcessLauncher::launchProcess):
+        * UIProcess/Plugins/gtk/PluginInfoCache.cpp: Removed.
+        * UIProcess/Plugins/gtk/PluginInfoCache.h: Removed.
+        * UIProcess/Plugins/unix/PluginInfoStoreUnix.cpp: Removed.
+        * UIProcess/Plugins/unix/PluginProcessProxyUnix.cpp: Removed.
+        * UIProcess/WebPageProxy.h:
+        * UIProcess/WebPageProxy.messages.in:
+        * UIProcess/gtk/WebPageProxyGtk.cpp:
+        * WebProcess/Plugins/Netscape/unix/NetscapePluginUnix.cpp: Removed.
+        * WebProcess/Plugins/Netscape/unix/NetscapePluginUnix.h: Removed.
+        * WebProcess/Plugins/Netscape/unix/PluginProxyUnix.cpp: Removed.
+        * WebProcess/Plugins/Netscape/x11/NetscapePluginX11.cpp: Removed.
+        * WebProcess/Plugins/Netscape/x11/NetscapePluginX11.h: Removed.
+        * WebProcess/Plugins/PluginController.h:
+        * WebProcess/Plugins/PluginView.cpp:
+        * WebProcess/Plugins/PluginView.h:
+
 2020-08-17  Youenn Fablet  <[email protected]>
 
         Set Sec-WebSocket-Protocol for WebSocket NSURLSession code path

Modified: trunk/Source/WebKit/PlatformGTK.cmake (265752 => 265753)


--- trunk/Source/WebKit/PlatformGTK.cmake	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/PlatformGTK.cmake	2020-08-17 12:41:09 UTC (rev 265753)
@@ -4,7 +4,6 @@
 set(WebProcess_OUTPUT_NAME WebKitWebProcess)
 set(NetworkProcess_OUTPUT_NAME WebKitNetworkProcess)
 set(GPUProcess_OUTPUT_NAME WebKitGPUProcess)
-set(PluginProcess_OUTPUT_NAME WebKitPluginProcess)
 
 file(MAKE_DIRECTORY ${DERIVED_SOURCES_WEBKIT2GTK_API_DIR})
 file(MAKE_DIRECTORY ${FORWARDING_HEADERS_WEBKIT2GTK_DIR})
@@ -404,7 +403,6 @@
     "${WEBKIT_DIR}/Shared/API/glib"
     "${WEBKIT_DIR}/Shared/CoordinatedGraphics"
     "${WEBKIT_DIR}/Shared/CoordinatedGraphics/threadedcompositor"
-    "${WEBKIT_DIR}/Shared/Plugins/unix"
     "${WEBKIT_DIR}/Shared/glib"
     "${WEBKIT_DIR}/Shared/gtk"
     "${WEBKIT_DIR}/Shared/linux"
@@ -417,7 +415,6 @@
     "${WEBKIT_DIR}/UIProcess/CoordinatedGraphics"
     "${WEBKIT_DIR}/UIProcess/Inspector/glib"
     "${WEBKIT_DIR}/UIProcess/Inspector/gtk"
-    "${WEBKIT_DIR}/UIProcess/Plugins/gtk"
     "${WEBKIT_DIR}/UIProcess/geoclue"
     "${WEBKIT_DIR}/UIProcess/glib"
     "${WEBKIT_DIR}/UIProcess/gstreamer"
@@ -429,8 +426,6 @@
     "${WEBKIT_DIR}/WebProcess/InjectedBundle/API/gtk"
     "${WEBKIT_DIR}/WebProcess/InjectedBundle/API/gtk/DOM"
     "${WEBKIT_DIR}/WebProcess/Inspector/gtk"
-    "${WEBKIT_DIR}/WebProcess/Plugins/Netscape/unix"
-    "${WEBKIT_DIR}/WebProcess/Plugins/Netscape/x11"
     "${WEBKIT_DIR}/WebProcess/gtk"
     "${WEBKIT_DIR}/WebProcess/soup"
     "${WEBKIT_DIR}/WebProcess/WebCoreSupport/gtk"
@@ -592,11 +587,6 @@
     )
 endif ()
 
-# GTK3 PluginProcess
-list(APPEND PluginProcess_SOURCES
-    PluginProcess/EntryPoint/unix/PluginProcessMain.cpp
-)
-
 # Commands for building the built-in injected bundle.
 add_library(webkit2gtkinjectedbundle MODULE "${WEBKIT_DIR}/WebProcess/InjectedBundle/API/glib/WebKitInjectedBundleMain.cpp")
 ADD_WEBKIT_PREFIX_HEADER(webkit2gtkinjectedbundle)

Modified: trunk/Source/WebKit/SourcesGTK.txt (265752 => 265753)


--- trunk/Source/WebKit/SourcesGTK.txt	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/SourcesGTK.txt	2020-08-17 12:41:09 UTC (rev 265753)
@@ -60,10 +60,6 @@
 Platform/unix/LoggingUnix.cpp
 Platform/unix/SharedMemoryUnix.cpp
 
-PluginProcess/unix/PluginControllerProxyUnix.cpp
-PluginProcess/unix/PluginProcessMainUnix.cpp
-PluginProcess/unix/PluginProcessUnix.cpp
-
 Shared/API/c/cairo/WKImageCairo.cpp
 
 Shared/API/glib/WebKitContextMenu.cpp @no-unify
@@ -81,11 +77,6 @@
 Shared/CoordinatedGraphics/threadedcompositor/ThreadedDisplayRefreshMonitor.cpp
 Shared/CoordinatedGraphics/threadedcompositor/ThreadedCompositor.cpp
 
-Shared/Plugins/Netscape/NetscapePluginModuleNone.cpp
-Shared/Plugins/Netscape/unix/NetscapePluginModuleUnix.cpp
-
-Shared/Plugins/unix/PluginSearchPath.cpp
-
 Shared/cairo/ShareableBitmapCairo.cpp
 
 Shared/glib/ArgumentCodersGLib.cpp
@@ -240,11 +231,6 @@
 
 UIProcess/linux/MemoryPressureMonitor.cpp
 
-UIProcess/Plugins/gtk/PluginInfoCache.cpp
-
-UIProcess/Plugins/unix/PluginInfoStoreUnix.cpp
-UIProcess/Plugins/unix/PluginProcessProxyUnix.cpp
-
 UIProcess/WebsiteData/soup/WebsiteDataStoreSoup.cpp
 UIProcess/WebsiteData/unix/WebsiteDataStoreUnix.cpp
 
@@ -415,11 +401,6 @@
 
 WebProcess/MediaCache/WebMediaKeyStorageManager.cpp
 
-WebProcess/Plugins/Netscape/unix/NetscapePluginUnix.cpp @no-unify
-WebProcess/Plugins/Netscape/unix/PluginProxyUnix.cpp @no-unify
-
-WebProcess/Plugins/Netscape/x11/NetscapePluginX11.cpp @no-unify
-
 WebProcess/WebCoreSupport/glib/WebEditorClientGLib.cpp
 
 WebProcess/WebCoreSupport/gtk/WebContextMenuClientGtk.cpp
@@ -452,5 +433,3 @@
 
 WebProcess/gtk/WaylandCompositorDisplay.cpp
 WebProcess/gtk/WebProcessMainGtk.cpp
-
-WebProcess/Plugins/Netscape/NetscapePluginNone.cpp

Modified: trunk/Source/WebKit/SourcesWPE.txt (265752 => 265753)


--- trunk/Source/WebKit/SourcesWPE.txt	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/SourcesWPE.txt	2020-08-17 12:41:09 UTC (rev 265753)
@@ -60,10 +60,6 @@
 Platform/unix/LoggingUnix.cpp
 Platform/unix/SharedMemoryUnix.cpp
 
-PluginProcess/unix/PluginControllerProxyUnix.cpp
-PluginProcess/unix/PluginProcessMainUnix.cpp
-PluginProcess/unix/PluginProcessUnix.cpp
-
 Shared/API/c/cairo/WKImageCairo.cpp
 
 Shared/API/glib/WebKitContextMenu.cpp @no-unify
@@ -81,9 +77,6 @@
 Shared/CoordinatedGraphics/threadedcompositor/ThreadedCompositor.cpp
 Shared/CoordinatedGraphics/threadedcompositor/ThreadedDisplayRefreshMonitor.cpp
 
-Shared/Plugins/Netscape/NetscapePluginModuleNone.cpp
-Shared/Plugins/Netscape/unix/NetscapePluginModuleUnix.cpp
-
 Shared/cairo/ShareableBitmapCairo.cpp
 
 Shared/glib/ArgumentCodersGLib.cpp
@@ -210,9 +203,6 @@
 UIProcess/Launcher/glib/BubblewrapLauncher.cpp
 UIProcess/Launcher/glib/FlatpakLauncher.cpp
 
-UIProcess/Plugins/unix/PluginInfoStoreUnix.cpp
-UIProcess/Plugins/unix/PluginProcessProxyUnix.cpp
-
 UIProcess/WebsiteData/soup/WebsiteDataStoreSoup.cpp
 UIProcess/WebsiteData/unix/WebsiteDataStoreUnix.cpp
 
@@ -250,8 +240,6 @@
 
 WebProcess/MediaCache/WebMediaKeyStorageManager.cpp
 
-WebProcess/Plugins/Netscape/NetscapePluginNone.cpp @no-unify
-
 WebProcess/WebCoreSupport/glib/WebEditorClientGLib.cpp
 
 WebProcess/WebCoreSupport/soup/WebFrameNetworkingContext.cpp

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitMimeInfo.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitMimeInfo.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitMimeInfo.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -20,33 +20,13 @@
 #include "config.h"
 #include "WebKitMimeInfo.h"
 
-#include "WebKitMimeInfoPrivate.h"
-#include <wtf/glib/GRefPtr.h>
-#include <wtf/text/CString.h>
-
 struct _WebKitMimeInfo {
-    _WebKitMimeInfo(const WebCore::MimeClassInfo& mimeInfo)
-        : mimeInfo(mimeInfo)
-    {
-    }
-
-    WebCore::MimeClassInfo mimeInfo;
-    CString mimeType;
-    CString description;
-    GRefPtr<GPtrArray> extensions;
-
-    int referenceCount { 0 };
 };
 
+ALLOW_DEPRECATED_DECLARATIONS_BEGIN
 G_DEFINE_BOXED_TYPE(WebKitMimeInfo, webkit_mime_info, webkit_mime_info_ref, webkit_mime_info_unref)
+ALLOW_DEPRECATED_DECLARATIONS_END
 
-WebKitMimeInfo* webkitMimeInfoCreate(const WebCore::MimeClassInfo& mimeInfo)
-{
-    WebKitMimeInfo* info = static_cast<WebKitMimeInfo*>(fastMalloc(sizeof(WebKitMimeInfo)));
-    new (info) WebKitMimeInfo(mimeInfo);
-    return info;
-}
-
 /**
  * webkit_mime_info_ref:
  * @info: a #WebKitMimeInfo
@@ -55,11 +35,12 @@
  * function is MT-safe and may be called from any thread.
  *
  * Returns: The passed in #WebKitMimeInfo
+ *
+ * Deprecated: 2.32
  */
-WebKitMimeInfo* webkit_mime_info_ref(WebKitMimeInfo* info)
+WebKitMimeInfo* webkit_mime_info_ref(WebKitMimeInfo*)
 {
-    g_atomic_int_inc(&info->referenceCount);
-    return info;
+    return nullptr;
 }
 
 /**
@@ -70,13 +51,11 @@
  * reference count drops to 0, all memory allocated by the #WebKitMimeInfo is
  * released. This function is MT-safe and may be called from any
  * thread.
+ *
+ * Deprecated: 2.32
  */
-void webkit_mime_info_unref(WebKitMimeInfo* info)
+void webkit_mime_info_unref(WebKitMimeInfo*)
 {
-    if (g_atomic_int_dec_and_test(&info->referenceCount)) {
-        info->~WebKitMimeInfo();
-        fastFree(info);
-    }
 }
 
 /**
@@ -84,17 +63,12 @@
  * @info: a #WebKitMimeInfo
  *
  * Returns: the MIME type of @info
+ *
+ * Deprecated: 2.32
  */
-const char* webkit_mime_info_get_mime_type(WebKitMimeInfo* info)
+const char* webkit_mime_info_get_mime_type(WebKitMimeInfo*)
 {
-    if (!info->mimeType.isNull())
-        return info->mimeType.data();
-
-    if (info->mimeInfo.type.isEmpty())
-        return 0;
-
-    info->mimeType = info->mimeInfo.type.utf8();
-    return info->mimeType.data();
+    return nullptr;
 }
 
 /**
@@ -102,17 +76,12 @@
  * @info: a #WebKitMimeInfo
  *
  * Returns: the description of the MIME type of @info
+ *
+ * Deprecated: 2.32
  */
-const char* webkit_mime_info_get_description(WebKitMimeInfo* info)
+const char* webkit_mime_info_get_description(WebKitMimeInfo*)
 {
-    if (!info->description.isNull())
-        return info->description.data();
-
-    if (info->mimeInfo.desc.isEmpty())
-        return 0;
-
-    info->description = info->mimeInfo.desc.utf8();
-    return info->description.data();
+    return nullptr;
 }
 
 /**
@@ -124,22 +93,10 @@
  *
  * Returns: (array zero-terminated=1) (transfer none): a
  *     %NULL-terminated array of strings
+ *
+ * Deprecated: 2.32
  */
-const char* const* webkit_mime_info_get_extensions(WebKitMimeInfo* info)
+const char* const* webkit_mime_info_get_extensions(WebKitMimeInfo*)
 {
-    if (info->extensions)
-        return reinterpret_cast<gchar**>(info->extensions->pdata);
-
-    if (info->mimeInfo.extensions.isEmpty())
-        return 0;
-
-    info->extensions = adoptGRef(g_ptr_array_new_with_free_func(g_free));
-    for (size_t i = 0; i < info->mimeInfo.extensions.size(); ++i) {
-        if (info->mimeInfo.extensions[i].isEmpty())
-            continue;
-        g_ptr_array_add(info->extensions.get(), g_strdup(info->mimeInfo.extensions[i].utf8().data()));
-    }
-    g_ptr_array_add(info->extensions.get(), 0);
-
-    return reinterpret_cast<gchar**>(info->extensions->pdata);
+    return nullptr;
 }

Deleted: trunk/Source/WebKit/UIProcess/API/glib/WebKitMimeInfoPrivate.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitMimeInfoPrivate.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitMimeInfoPrivate.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,25 +0,0 @@
-/*
- * Copyright (C) 2012 Igalia S.L.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
-
-#pragma once
-
-#include "WebKitMimeInfo.h"
-#include <WebCore/PluginData.h>
-
-WebKitMimeInfo* webkitMimeInfoCreate(const WebCore::MimeClassInfo&);

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitPlugin.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitPlugin.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitPlugin.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -20,13 +20,8 @@
 #include "config.h"
 #include "WebKitPlugin.h"
 
-#include "WebKitMimeInfoPrivate.h"
-#include "WebKitPluginPrivate.h"
 #include <wtf/glib/WTFGType.h>
-#include <wtf/text/CString.h>
 
-using namespace WebKit;
-
 /**
  * SECTION: WebKitPlugin
  * @Short_description: Represents a plugin, enabling fine-grained control
@@ -39,52 +34,31 @@
  * be obtained from the #WebKitWebContext, with
  * webkit_web_context_get_plugins().
  *
+ * Deprecated: 2.32
  */
 
 struct _WebKitPluginPrivate {
-    ~_WebKitPluginPrivate()
-    {
-        g_list_free_full(mimeInfoList, reinterpret_cast<GDestroyNotify>(webkit_mime_info_unref));
-    }
-
-    PluginModuleInfo pluginInfo;
-    CString name;
-    CString description;
-    CString path;
-    GList* mimeInfoList;
 };
 
+ALLOW_DEPRECATED_DECLARATIONS_BEGIN
 WEBKIT_DEFINE_TYPE(WebKitPlugin, webkit_plugin, G_TYPE_OBJECT)
+ALLOW_DEPRECATED_DECLARATIONS_END
 
 static void webkit_plugin_class_init(WebKitPluginClass*)
 {
 }
 
-WebKitPlugin* webkitPluginCreate(const PluginModuleInfo& pluginInfo)
-{
-    WebKitPlugin* plugin = WEBKIT_PLUGIN(g_object_new(WEBKIT_TYPE_PLUGIN, NULL));
-    plugin->priv->pluginInfo = pluginInfo;
-    return plugin;
-}
-
 /**
  * webkit_plugin_get_name:
  * @plugin: a #WebKitPlugin
  *
  * Returns: the name of the plugin.
+ *
+ * Deprecated: 2.32
  */
-const char* webkit_plugin_get_name(WebKitPlugin* plugin)
+const char* webkit_plugin_get_name(WebKitPlugin*)
 {
-    g_return_val_if_fail(WEBKIT_IS_PLUGIN(plugin), 0);
-
-    if (!plugin->priv->name.isNull())
-        return plugin->priv->name.data();
-
-    if (plugin->priv->pluginInfo.info.name.isEmpty())
-        return 0;
-
-    plugin->priv->name = plugin->priv->pluginInfo.info.name.utf8();
-    return plugin->priv->name.data();
+    return nullptr;
 }
 
 /**
@@ -92,19 +66,12 @@
  * @plugin: a #WebKitPlugin
  *
  * Returns: the description of the plugin.
+ *
+ * Deprecated: 2.32
  */
-const char* webkit_plugin_get_description(WebKitPlugin* plugin)
+const char* webkit_plugin_get_description(WebKitPlugin*)
 {
-    g_return_val_if_fail(WEBKIT_IS_PLUGIN(plugin), 0);
-
-    if (!plugin->priv->description.isNull())
-        return plugin->priv->description.data();
-
-    if (plugin->priv->pluginInfo.info.desc.isEmpty())
-        return 0;
-
-    plugin->priv->description = plugin->priv->pluginInfo.info.desc.utf8();
-    return plugin->priv->description.data();
+    return nullptr;
 }
 
 /**
@@ -112,19 +79,12 @@
  * @plugin: a #WebKitPlugin
  *
  * Returns: the absolute path where the plugin is installed.
+ *
+ * Deprecated: 2.32
  */
-const char* webkit_plugin_get_path(WebKitPlugin* plugin)
+const char* webkit_plugin_get_path(WebKitPlugin*)
 {
-    g_return_val_if_fail(WEBKIT_IS_PLUGIN(plugin), 0);
-
-    if (!plugin->priv->path.isNull())
-        return plugin->priv->path.data();
-
-    if (plugin->priv->pluginInfo.path.isEmpty())
-        return 0;
-
-    plugin->priv->path = plugin->priv->pluginInfo.path.utf8();
-    return plugin->priv->path.data();
+    return nullptr;
 }
 
 /**
@@ -135,18 +95,10 @@
  * as a list of #WebKitMimeInfo.
  *
  * Returns: (element-type WebKitMimeInfo) (transfer none): a #GList of #WebKitMimeInfo.
+ *
+ * Deprecated: 2.32
  */
-GList* webkit_plugin_get_mime_info_list(WebKitPlugin* plugin)
+GList* webkit_plugin_get_mime_info_list(WebKitPlugin*)
 {
-    g_return_val_if_fail(WEBKIT_IS_PLUGIN(plugin), 0);
-
-    if (plugin->priv->mimeInfoList)
-        return plugin->priv->mimeInfoList;
-
-    if (plugin->priv->pluginInfo.info.mimes.isEmpty())
-        return 0;
-
-    for (size_t i = 0; i < plugin->priv->pluginInfo.info.mimes.size(); ++i)
-        plugin->priv->mimeInfoList = g_list_prepend(plugin->priv->mimeInfoList, webkitMimeInfoCreate(plugin->priv->pluginInfo.info.mimes[i]));
-    return plugin->priv->mimeInfoList;
+    return nullptr;
 }

Deleted: trunk/Source/WebKit/UIProcess/API/glib/WebKitPluginPrivate.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitPluginPrivate.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitPluginPrivate.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,25 +0,0 @@
-/*
- * Copyright (C) 2012 Igalia S.L.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
-
-#pragma once
-
-#include "PluginModuleInfo.h"
-#include "WebKitPlugin.h"
-
-WebKitPlugin* webkitPluginCreate(const WebKit::PluginModuleInfo&);

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitSettings.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitSettings.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitSettings.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -240,7 +240,6 @@
         webkit_settings_set_enable_frame_flattening(settings, g_value_get_boolean(value));
         break;
     case PROP_ENABLE_PLUGINS:
-        webkit_settings_set_enable_plugins(settings, g_value_get_boolean(value));
         break;
     case PROP_ENABLE_JAVA:
         webkit_settings_set_enable_java(settings, g_value_get_boolean(value));
@@ -441,7 +440,7 @@
         g_value_set_boolean(value, webkit_settings_get_enable_frame_flattening(settings));
         break;
     case PROP_ENABLE_PLUGINS:
-        g_value_set_boolean(value, webkit_settings_get_enable_plugins(settings));
+        g_value_set_boolean(value, FALSE);
         break;
     case PROP_ENABLE_JAVA:
         g_value_set_boolean(value, webkit_settings_get_enable_java(settings));
@@ -739,6 +738,8 @@
      * WebKitSettings:enable-plugins:
      *
      * Determines whether or not plugins on the page are enabled.
+     *
+     * Deprecated: 2.32
      */
     g_object_class_install_property(gObjectClass,
                                     PROP_ENABLE_PLUGINS,
@@ -745,7 +746,7 @@
                                     g_param_spec_boolean("enable-plugins",
                                                          _("Enable plugins"),
                                                          _("Enable embedded plugin objects."),
-                                                         TRUE,
+                                                         FALSE,
                                                          readWriteConstructParamFlags));
 
     /**
@@ -1889,12 +1890,16 @@
  * Get the #WebKitSettings:enable-plugins property.
  *
  * Returns: %TRUE If plugins are enabled or %FALSE otherwise.
+ *
+ * Deprecated: 2.32
  */
 gboolean webkit_settings_get_enable_plugins(WebKitSettings* settings)
 {
     g_return_val_if_fail(WEBKIT_IS_SETTINGS(settings), FALSE);
 
-    return settings->priv->preferences->pluginsEnabled();
+    g_warning("webkit_settings_get_enable_plugins is deprecated and always returns FALSE. Plugins are no longer supported.");
+
+    return FALSE;
 }
 
 /**
@@ -1903,18 +1908,14 @@
  * @enabled: Value to be set
  *
  * Set the #WebKitSettings:enable-plugins property.
+ *
+ * Deprecated: 2.32
  */
-void webkit_settings_set_enable_plugins(WebKitSettings* settings, gboolean enabled)
+void webkit_settings_set_enable_plugins(WebKitSettings* settings, gboolean)
 {
     g_return_if_fail(WEBKIT_IS_SETTINGS(settings));
 
-    WebKitSettingsPrivate* priv = settings->priv;
-    bool currentValue = priv->preferences->pluginsEnabled();
-    if (currentValue == enabled)
-        return;
-
-    priv->preferences->setPluginsEnabled(enabled);
-    g_object_notify(G_OBJECT(settings), "enable-plugins");
+    g_warning("webkit_settings_set_enable_plugins is deprecated and does nothing. Plugins are no longer supported.");
 }
 
 /**

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitWebContext.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitWebContext.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitWebContext.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -41,7 +41,6 @@
 #include "WebKitInjectedBundleClient.h"
 #include "WebKitNetworkProxySettingsPrivate.h"
 #include "WebKitNotificationProvider.h"
-#include "WebKitPluginPrivate.h"
 #include "WebKitPrivate.h"
 #include "WebKitProtocolHandler.h"
 #include "WebKitSecurityManagerPrivate.h"
@@ -1152,33 +1151,14 @@
  * @directory: the directory to add
  *
  * Set an additional directory where WebKit will look for plugins.
+ *
+ * Deprecated: 2.32
  */
-void webkit_web_context_set_additional_plugins_directory(WebKitWebContext* context, const char* directory)
+void webkit_web_context_set_additional_plugins_directory(WebKitWebContext*, const char*)
 {
-    g_return_if_fail(WEBKIT_IS_WEB_CONTEXT(context));
-    g_return_if_fail(directory);
-
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    context->priv->processPool->setAdditionalPluginsDirectory(FileSystem::stringFromFileSystemRepresentation(directory));
-#endif
+    g_warning("webkit_web_context_set_additional_plugins_directory is deprecated and does nothing. Netscape plugins are no longer supported.");
 }
 
-static void destroyPluginList(GList* plugins)
-{
-    g_list_free_full(plugins, g_object_unref);
-}
-
-static void webkitWebContextGetPluginThread(GTask* task, gpointer object, gpointer /* taskData */, GCancellable*)
-{
-    GList* returnValue = 0;
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    Vector<PluginModuleInfo> plugins = WEBKIT_WEB_CONTEXT(object)->priv->processPool->pluginInfoStore().plugins();
-    for (size_t i = 0; i < plugins.size(); ++i)
-        returnValue = g_list_prepend(returnValue, webkitPluginCreate(plugins[i]));
-#endif
-    g_task_return_pointer(task, returnValue, reinterpret_cast<GDestroyNotify>(destroyPluginList));
-}
-
 /**
  * webkit_web_context_get_plugins:
  * @context: a #WebKitWebContext
@@ -1190,13 +1170,17 @@
  *
  * When the operation is finished, @callback will be called. You can then call
  * webkit_web_context_get_plugins_finish() to get the result of the operation.
+ *
+ * Deprecated: 2.32
  */
 void webkit_web_context_get_plugins(WebKitWebContext* context, GCancellable* cancellable, GAsyncReadyCallback callback, gpointer userData)
 {
     g_return_if_fail(WEBKIT_IS_WEB_CONTEXT(context));
 
+    g_warning("webkit_web_context_get_plugins is deprecated and always returns an empty list. Netscape plugins are no longer supported.");
+
     GRefPtr<GTask> task = adoptGRef(g_task_new(context, cancellable, callback, userData));
-    g_task_run_in_thread(task.get(), webkitWebContextGetPluginThread);
+    g_task_return_pointer(task.get(), nullptr, nullptr);
 }
 
 /**
@@ -1209,11 +1193,13 @@
  *
  * Returns: (element-type WebKitPlugin) (transfer full): a #GList of #WebKitPlugin. You must free the #GList with
  *    g_list_free() and unref the #WebKitPlugin<!-- -->s with g_object_unref() when you're done with them.
+ *
+ * Deprecated: 2.32
  */
 GList* webkit_web_context_get_plugins_finish(WebKitWebContext* context, GAsyncResult* result, GError** error)
 {
-    g_return_val_if_fail(WEBKIT_IS_WEB_CONTEXT(context), 0);
-    g_return_val_if_fail(g_task_is_valid(result, context), 0);
+    g_return_val_if_fail(WEBKIT_IS_WEB_CONTEXT(context), nullptr);
+    g_return_val_if_fail(g_task_is_valid(result, context), nullptr);
 
     return static_cast<GList*>(g_task_propagate_pointer(G_TASK(result), error));
 }
@@ -1244,9 +1230,7 @@
  *     const gchar  *path;
  *
  *     path = webkit_uri_scheme_request_get_path (request);
- *     if (!g_strcmp0 (path, "plugins")) {
- *         /<!-- -->* Create a GInputStream with the contents of plugins about page, and set its length to stream_length *<!-- -->/
- *     } else if (!g_strcmp0 (path, "memory")) {
+ *     if (!g_strcmp0 (path, "memory")) {
  *         /<!-- -->* Create a GInputStream with the contents of memory about page, and set its length to stream_length *<!-- -->/
  *     } else if (!g_strcmp0 (path, "applications")) {
  *         /<!-- -->* Create a GInputStream with the contents of applications about page, and set its length to stream_length *<!-- -->/

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitWebView.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitWebView.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitWebView.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -470,8 +470,7 @@
 static gboolean webkitWebViewLoadFail(WebKitWebView* webView, WebKitLoadEvent, const char* failingURI, GError* error)
 {
     if (g_error_matches(error, WEBKIT_NETWORK_ERROR, WEBKIT_NETWORK_ERROR_CANCELLED)
-        || g_error_matches(error, WEBKIT_POLICY_ERROR, WEBKIT_POLICY_ERROR_FRAME_LOAD_INTERRUPTED_BY_POLICY_CHANGE)
-        || g_error_matches(error, WEBKIT_PLUGIN_ERROR, WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD))
+        || g_error_matches(error, WEBKIT_POLICY_ERROR, WEBKIT_POLICY_ERROR_FRAME_LOAD_INTERRUPTED_BY_POLICY_CHANGE))
         return FALSE;
 
     GUniquePtr<char> htmlString(g_strdup_printf("<html><body>%s</body></html>", error->message));

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitWebsiteData.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitWebsiteData.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitWebsiteData.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -74,9 +74,6 @@
         WebsiteDataType::WebSQLDatabases,
         WebsiteDataType::IndexedDBDatabases,
         WebsiteDataType::HSTSCache,
-#if ENABLE(NETSCAPE_PLUGIN_API)
-        WebsiteDataType::PlugInData,
-#endif
         WebsiteDataType::Cookies,
         WebsiteDataType::DeviceIdHashSalt,
         WebsiteDataType::ResourceLoadStatistics,
@@ -104,10 +101,6 @@
         returnValue |= WEBKIT_WEBSITE_DATA_INDEXEDDB_DATABASES;
     if (types.contains(WebsiteDataType::HSTSCache))
         returnValue |= WEBKIT_WEBSITE_DATA_HSTS_CACHE;
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    if (types.contains(WebsiteDataType::PlugInData))
-        returnValue |= WEBKIT_WEBSITE_DATA_PLUGIN_DATA;
-#endif
     if (types.contains(WebsiteDataType::Cookies))
         returnValue |= WEBKIT_WEBSITE_DATA_COOKIES;
     if (types.contains(WebsiteDataType::DeviceIdHashSalt))

Modified: trunk/Source/WebKit/UIProcess/API/glib/WebKitWebsiteDataManager.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/glib/WebKitWebsiteDataManager.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/glib/WebKitWebsiteDataManager.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -925,10 +925,6 @@
         returnValue.add(WebsiteDataType::IndexedDBDatabases);
     if (types & WEBKIT_WEBSITE_DATA_HSTS_CACHE)
         returnValue.add(WebsiteDataType::HSTSCache);
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    if (types & WEBKIT_WEBSITE_DATA_PLUGIN_DATA)
-        returnValue.add(WebsiteDataType::PlugInData);
-#endif
     if (types & WEBKIT_WEBSITE_DATA_COOKIES)
         returnValue.add(WebsiteDataType::Cookies);
     if (types & WEBKIT_WEBSITE_DATA_DEVICE_ID_HASH_SALT)

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitError.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitMimeInfo.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitMimeInfo.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -34,22 +34,22 @@
 typedef struct _WebKitMimeInfo WebKitMimeInfo;
 
 
-WEBKIT_API GType
+WEBKIT_DEPRECATED GType
 webkit_mime_info_get_type        (void);
 
-WEBKIT_API WebKitMimeInfo *
+WEBKIT_DEPRECATED WebKitMimeInfo *
 webkit_mime_info_ref             (WebKitMimeInfo *info);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_mime_info_unref           (WebKitMimeInfo *info);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_mime_info_get_mime_type   (WebKitMimeInfo *info);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_mime_info_get_description (WebKitMimeInfo *info);
 
-WEBKIT_API const gchar * const *
+WEBKIT_DEPRECATED const gchar * const *
 webkit_mime_info_get_extensions  (WebKitMimeInfo *info);
 
 G_END_DECLS

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitPlugin.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitPlugin.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitPlugin.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -55,19 +55,19 @@
     void (*_webkit_reserved3) (void);
 };
 
-WEBKIT_API GType
+WEBKIT_DEPRECATED GType
 webkit_plugin_get_type           (void);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_plugin_get_name           (WebKitPlugin *plugin);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_plugin_get_description    (WebKitPlugin *plugin);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_plugin_get_path           (WebKitPlugin *plugin);
 
-WEBKIT_API GList *
+WEBKIT_DEPRECATED GList *
 webkit_plugin_get_mime_info_list (WebKitPlugin *plugin);
 
 G_END_DECLS

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitSettings.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitSettings.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitSettings.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -147,10 +147,10 @@
 webkit_settings_set_enable_frame_flattening                    (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_plugins                             (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_plugins                             (WebKitSettings *settings,
                                                                 gboolean        enabled);
 

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitWebContext.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitWebContext.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitWebContext.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -228,17 +228,17 @@
 WEBKIT_API WebKitSecurityManager *
 webkit_web_context_get_security_manager             (WebKitWebContext              *context);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_web_context_set_additional_plugins_directory (WebKitWebContext              *context,
                                                      const gchar                   *directory);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_web_context_get_plugins                      (WebKitWebContext              *context,
                                                      GCancellable                  *cancellable,
                                                      GAsyncReadyCallback            callback,
                                                      gpointer                       user_data);
 
-WEBKIT_API GList *
+WEBKIT_DEPRECATED GList *
 webkit_web_context_get_plugins_finish               (WebKitWebContext              *context,
                                                      GAsyncResult                  *result,
                                                      GError                       **error);

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitWebsiteData.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitWebsiteData.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitWebsiteData.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -42,7 +42,7 @@
  * @WEBKIT_WEBSITE_DATA_LOCAL_STORAGE: Local storage data.
  * @WEBKIT_WEBSITE_DATA_WEBSQL_DATABASES: WebSQL databases. Deprecated 2.24
  * @WEBKIT_WEBSITE_DATA_INDEXEDDB_DATABASES: IndexedDB databases.
- * @WEBKIT_WEBSITE_DATA_PLUGIN_DATA: Plugins data.
+ * @WEBKIT_WEBSITE_DATA_PLUGIN_DATA: Plugins data. Deprecated 2.32
  * @WEBKIT_WEBSITE_DATA_COOKIES: Cookies.
  * @WEBKIT_WEBSITE_DATA_DEVICE_ID_HASH_SALT: Hash salt used to generate the device ids used by webpages. Since 2.24
  * @WEBKIT_WEBSITE_DATA_HSTS_CACHE: HSTS cache. Since 2.26

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitError.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitMimeInfo.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitMimeInfo.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -34,22 +34,22 @@
 typedef struct _WebKitMimeInfo WebKitMimeInfo;
 
 
-WEBKIT_API GType
+WEBKIT_DEPRECATED GType
 webkit_mime_info_get_type        (void);
 
-WEBKIT_API WebKitMimeInfo *
+WEBKIT_DEPRECATED WebKitMimeInfo *
 webkit_mime_info_ref             (WebKitMimeInfo *info);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_mime_info_unref           (WebKitMimeInfo *info);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_mime_info_get_mime_type   (WebKitMimeInfo *info);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_mime_info_get_description (WebKitMimeInfo *info);
 
-WEBKIT_API const gchar * const *
+WEBKIT_DEPRECATED const gchar * const *
 webkit_mime_info_get_extensions  (WebKitMimeInfo *info);
 
 G_END_DECLS

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitPlugin.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitPlugin.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitPlugin.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -55,19 +55,19 @@
     void (*_webkit_reserved3) (void);
 };
 
-WEBKIT_API GType
+WEBKIT_DEPRECATED GType
 webkit_plugin_get_type           (void);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_plugin_get_name           (WebKitPlugin *plugin);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_plugin_get_description    (WebKitPlugin *plugin);
 
-WEBKIT_API const gchar *
+WEBKIT_DEPRECATED const gchar *
 webkit_plugin_get_path           (WebKitPlugin *plugin);
 
-WEBKIT_API GList *
+WEBKIT_DEPRECATED GList *
 webkit_plugin_get_mime_info_list (WebKitPlugin *plugin);
 
 G_END_DECLS

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitSettings.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitSettings.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitSettings.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -131,10 +131,10 @@
 webkit_settings_set_enable_frame_flattening                    (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_plugins                             (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_plugins                             (WebKitSettings *settings,
                                                                 gboolean        enabled);
 

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitWebContext.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitWebContext.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitWebContext.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -228,17 +228,17 @@
 WEBKIT_API WebKitSecurityManager *
 webkit_web_context_get_security_manager             (WebKitWebContext              *context);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_web_context_set_additional_plugins_directory (WebKitWebContext              *context,
                                                      const gchar                   *directory);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_web_context_get_plugins                      (WebKitWebContext              *context,
                                                      GCancellable                  *cancellable,
                                                      GAsyncReadyCallback            callback,
                                                      gpointer                       user_data);
 
-WEBKIT_API GList *
+WEBKIT_DEPRECATED GList *
 webkit_web_context_get_plugins_finish               (WebKitWebContext              *context,
                                                      GAsyncResult                  *result,
                                                      GError                       **error);

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitWebsiteData.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitWebsiteData.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitWebsiteData.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -42,7 +42,7 @@
  * @WEBKIT_WEBSITE_DATA_LOCAL_STORAGE: Local storage data.
  * @WEBKIT_WEBSITE_DATA_WEBSQL_DATABASES: WebSQL databases. Deprecated 2.24
  * @WEBKIT_WEBSITE_DATA_INDEXEDDB_DATABASES: IndexedDB databases.
- * @WEBKIT_WEBSITE_DATA_PLUGIN_DATA: Plugins data.
+ * @WEBKIT_WEBSITE_DATA_PLUGIN_DATA: Plugins data. Deprecated 2.32
  * @WEBKIT_WEBSITE_DATA_COOKIES: Cookies.
  * @WEBKIT_WEBSITE_DATA_DEVICE_ID_HASH_SALT: Hash salt used to generate the device ids used by webpages. Since 2.24
  * @WEBKIT_WEBSITE_DATA_HSTS_CACHE: HSTS cache. Since 2.26

Modified: trunk/Source/WebKit/UIProcess/Launcher/glib/BubblewrapLauncher.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/Launcher/glib/BubblewrapLauncher.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/Launcher/glib/BubblewrapLauncher.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -718,13 +718,6 @@
 {
     ASSERT(launcher);
 
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    // It is impossible to know what access arbitrary plugins need and since it is for legacy
-    // reasons lets just leave it unsandboxed.
-    if (launchOptions.processType == ProcessLauncher::ProcessType::Plugin)
-        return adoptGRef(g_subprocess_launcher_spawnv(launcher, argv, error));
-#endif
-
     // For now we are just considering the network process trusted as it
     // requires a lot of access but doesn't execute arbitrary code like
     // the WebProcess where our focus lies.

Modified: trunk/Source/WebKit/UIProcess/Launcher/glib/ProcessLauncherGLib.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/Launcher/glib/ProcessLauncherGLib.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/Launcher/glib/ProcessLauncherGLib.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -111,21 +111,10 @@
 
     String executablePath;
     CString realExecutablePath;
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    String pluginPath;
-    CString realPluginPath;
-#endif
     switch (m_launchOptions.processType) {
     case ProcessLauncher::ProcessType::Web:
         executablePath = executablePathOfWebProcess();
         break;
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    case ProcessLauncher::ProcessType::Plugin:
-        executablePath = executablePathOfPluginProcess();
-        pluginPath = m_launchOptions.extraInitializationData.get("plugin-path");
-        realPluginPath = FileSystem::fileSystemRepresentation(pluginPath);
-        break;
-#endif
     case ProcessLauncher::ProcessType::Network:
         executablePath = executablePathOfNetworkProcess();
         break;
@@ -173,11 +162,7 @@
     if (configureJSCForTesting)
         argv[i++] = const_cast<char*>("--configure-jsc-for-testing");
 #endif
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    argv[i++] = const_cast<char*>(realPluginPath.data());
-#else
     argv[i++] = nullptr;
-#endif
     argv[i++] = nullptr;
 
     GRefPtr<GSubprocessLauncher> launcher = adoptGRef(g_subprocess_launcher_new(G_SUBPROCESS_FLAGS_INHERIT_FDS));

Modified: trunk/Source/WebKit/UIProcess/WebPageProxy.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/WebPageProxy.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/WebPageProxy.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -2209,12 +2209,6 @@
 
     void setRenderTreeSize(uint64_t treeSize) { m_renderTreeSize = treeSize; }
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-    void createPluginContainer(CompletionHandler<void(uint64_t)>&&);
-    void windowedPluginGeometryDidChange(const WebCore::IntRect& frameRect, const WebCore::IntRect& clipRect, uint64_t windowID);
-    void windowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID);
-#endif
-
     void processNextQueuedWheelEvent();
     void sendWheelEvent(const WebWheelEvent&);
     bool shouldProcessWheelEventNow(const WebWheelEvent&) const;

Modified: trunk/Source/WebKit/UIProcess/WebPageProxy.messages.in (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/WebPageProxy.messages.in	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/WebPageProxy.messages.in	2020-08-17 12:41:09 UTC (rev 265753)
@@ -390,13 +390,6 @@
     DictationAlternatives(WebCore::DictationContext dictationContext) -> (Vector<String> alternatives) Synchronous
 #endif
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-    # X11 windowed plugin messages
-    CreatePluginContainer() -> (uint64_t windowID) Synchronous
-    WindowedPluginGeometryDidChange(WebCore::IntRect frameRect, WebCore::IntRect clipRect, uint64_t windowID)
-    WindowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID)
-#endif
-
 #if PLATFORM(IOS_FAMILY)
     CouldNotRestorePageState()
     RestorePageState(Optional<WebCore::FloatPoint> scrollPosition, WebCore::FloatPoint scrollOrigin, WebCore::RectEdges<float> obscuredInsetsOnSave, double scale)

Modified: trunk/Source/WebKit/UIProcess/gtk/WebPageProxyGtk.cpp (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/gtk/WebPageProxyGtk.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/gtk/WebPageProxyGtk.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -41,10 +41,6 @@
 #include <WebCore/UserAgent.h>
 #include <wtf/NeverDestroyed.h>
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-#include <gtk/gtkx.h>
-#endif
-
 namespace WebKit {
 
 void WebPageProxy::platformInitialize()
@@ -96,62 +92,6 @@
     pageClient().selectionDidChange();
 }
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-typedef HashMap<uint64_t, GtkWidget* > PluginWindowMap;
-static PluginWindowMap& pluginWindowMap()
-{
-    static NeverDestroyed<PluginWindowMap> map;
-    return map;
-}
-
-static gboolean pluginContainerPlugRemoved(GtkSocket* socket)
-{
-    uint64_t windowID = static_cast<uint64_t>(gtk_socket_get_id(socket));
-    pluginWindowMap().remove(windowID);
-    return FALSE;
-}
-
-void WebPageProxy::createPluginContainer(CompletionHandler<void(uint64_t)>&& completionHandler)
-{
-    RELEASE_ASSERT(WebCore::PlatformDisplay::sharedDisplay().type() == WebCore::PlatformDisplay::Type::X11);
-    GtkWidget* socket = gtk_socket_new();
-    g_signal_connect(socket, "plug-removed", G_CALLBACK(pluginContainerPlugRemoved), 0);
-    gtk_container_add(GTK_CONTAINER(viewWidget()), socket);
-
-    uint64_t windowID = static_cast<uint64_t>(gtk_socket_get_id(GTK_SOCKET(socket)));
-    pluginWindowMap().set(windowID, socket);
-    completionHandler(windowID);
-}
-
-void WebPageProxy::windowedPluginGeometryDidChange(const WebCore::IntRect& frameRect, const WebCore::IntRect& clipRect, uint64_t windowID)
-{
-    GtkWidget* plugin = pluginWindowMap().get(windowID);
-    if (!plugin)
-        return;
-
-    if (gtk_widget_get_realized(plugin)) {
-        GdkRectangle clip = clipRect;
-        cairo_region_t* clipRegion = cairo_region_create_rectangle(&clip);
-        gdk_window_shape_combine_region(gtk_widget_get_window(plugin), clipRegion, 0, 0);
-        cairo_region_destroy(clipRegion);
-    }
-
-    webkitWebViewBaseChildMoveResize(WEBKIT_WEB_VIEW_BASE(viewWidget()), plugin, frameRect);
-}
-
-void WebPageProxy::windowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID)
-{
-    GtkWidget* plugin = pluginWindowMap().get(windowID);
-    if (!plugin)
-        return;
-
-    if (isVisible)
-        gtk_widget_show(plugin);
-    else
-        gtk_widget_hide(plugin);
-}
-#endif // PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-
 void WebPageProxy::setInputMethodState(Optional<InputMethodState>&& state)
 {
     webkitWebViewBaseSetInputMethodState(WEBKIT_WEB_VIEW_BASE(viewWidget()), WTFMove(state));

Modified: trunk/Source/WebKit/WebProcess/Plugins/PluginController.h (265752 => 265753)


--- trunk/Source/WebKit/WebProcess/Plugins/PluginController.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/WebProcess/Plugins/PluginController.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -144,13 +144,6 @@
     // Decrements a counter that, when it reaches 0, stops preventing the plug-in from being destroyed.
     virtual void unprotectPluginFromDestruction() = 0;
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-    // Create a plugin container for windowed plugins
-    virtual uint64_t createPluginContainer() = 0;
-    virtual void windowedPluginGeometryDidChange(const WebCore::IntRect& frameRect, const WebCore::IntRect& clipRect, uint64_t windowID) = 0;
-    virtual void windowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID) = 0;
-#endif
-
     // Called when the a plug-in instance is successfully initialized, either synchronously or asynchronously.
     virtual void didInitializePlugin() = 0;
     

Modified: trunk/Source/WebKit/WebProcess/Plugins/PluginView.cpp (265752 => 265753)


--- trunk/Source/WebKit/WebProcess/Plugins/PluginView.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/WebProcess/Plugins/PluginView.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -73,10 +73,6 @@
 #include <wtf/CompletionHandler.h>
 #include <wtf/text/StringBuilder.h>
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-#include <WebCore/PlatformDisplay.h>
-#endif
-
 namespace WebKit {
 using namespace JSC;
 using namespace WebCore;
@@ -1682,26 +1678,6 @@
     m_plugin->frameDidFail(request->requestID(), wasCancelled);
 }
 
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-uint64_t PluginView::createPluginContainer()
-{
-    uint64_t windowID = 0;
-    if (PlatformDisplay::sharedDisplay().type() == PlatformDisplay::Type::X11)
-        m_webPage->sendSync(Messages::WebPageProxy::CreatePluginContainer(), Messages::WebPageProxy::CreatePluginContainer::Reply(windowID));
-    return windowID;
-}
-
-void PluginView::windowedPluginGeometryDidChange(const WebCore::IntRect& frameRect, const WebCore::IntRect& clipRect, uint64_t windowID)
-{
-    m_webPage->send(Messages::WebPageProxy::WindowedPluginGeometryDidChange(frameRect, clipRect, windowID));
-}
-
-void PluginView::windowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID)
-{
-    m_webPage->send(Messages::WebPageProxy::WindowedPluginVisibilityDidChange(isVisible, windowID));
-}
-#endif
-
 #if PLATFORM(COCOA)
 static bool isAlmostSolidColor(BitmapImage* bitmap)
 {

Modified: trunk/Source/WebKit/WebProcess/Plugins/PluginView.h (265752 => 265753)


--- trunk/Source/WebKit/WebProcess/Plugins/PluginView.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/WebProcess/Plugins/PluginView.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -226,11 +226,6 @@
     bool artificialPluginInitializationDelayEnabled() const override;
     void protectPluginFromDestruction() override;
     void unprotectPluginFromDestruction() override;
-#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
-    uint64_t createPluginContainer() override;
-    void windowedPluginGeometryDidChange(const WebCore::IntRect& frameRect, const WebCore::IntRect& clipRect, uint64_t windowID) override;
-    void windowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID) override;
-#endif
 
     void didInitializePlugin() override;
     void didFailToInitializePlugin() override;

Modified: trunk/Source/cmake/OptionsGTK.cmake (265752 => 265753)


--- trunk/Source/cmake/OptionsGTK.cmake	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/cmake/OptionsGTK.cmake	2020-08-17 12:41:09 UTC (rev 265753)
@@ -181,6 +181,7 @@
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_MEDIA_STREAM PRIVATE ${ENABLE_EXPERIMENTAL_FEATURES})
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_MHTML PRIVATE ON)
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_MOUSE_CURSOR_SCALE PRIVATE ON)
+WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_NETSCAPE_PLUGIN_API PRIVATE OFF)
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_NETWORK_CACHE_SPECULATIVE_REVALIDATION PRIVATE ON)
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_NETWORK_CACHE_STALE_WHILE_REVALIDATE PRIVATE ON)
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_OFFSCREEN_CANVAS PRIVATE ${ENABLE_EXPERIMENTAL_FEATURES})
@@ -193,10 +194,6 @@
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_WEB_API_STATISTICS PRIVATE ON)
 WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_WEB_RTC PRIVATE ${ENABLE_EXPERIMENTAL_FEATURES})
 
-if (USE_GTK4)
-WEBKIT_OPTION_DEFAULT_PORT_VALUE(ENABLE_NETSCAPE_PLUGIN_API PRIVATE OFF)
-endif ()
-
 include(GStreamerDependencies)
 
 # Finalize the value for all options. Do not attempt to use an option before
@@ -207,17 +204,8 @@
 SET_AND_EXPOSE_TO_BUILD(WTF_PLATFORM_X11 ${ENABLE_X11_TARGET})
 SET_AND_EXPOSE_TO_BUILD(WTF_PLATFORM_WAYLAND ${ENABLE_WAYLAND_TARGET})
 
-if (ENABLE_NETSCAPE_PLUGIN_API)
-    # MOZ_X11 and XP_UNIX are required by npapi.h. Their value is not checked;
-    # only their definedness is. They should only be defined in the true case.
-    if (ENABLE_X11_TARGET)
-        SET_AND_EXPOSE_TO_BUILD(MOZ_X11 1)
-    endif ()
-    SET_AND_EXPOSE_TO_BUILD(XP_UNIX 1)
-endif ()
+SET_AND_EXPOSE_TO_BUILD(ENABLE_PLUGIN_PROCESS FALSE)
 
-SET_AND_EXPOSE_TO_BUILD(ENABLE_PLUGIN_PROCESS ${ENABLE_NETSCAPE_PLUGIN_API})
-
 add_definitions(-DBUILDING_GTK__=1)
 add_definitions(-DGETTEXT_PACKAGE="WebKit2GTK-${WEBKITGTK_API_VERSION}")
 add_definitions(-DWEBKITGTK_API_VERSION_STRING="${WEBKITGTK_API_VERSION}")

Modified: trunk/Tools/ChangeLog (265752 => 265753)


--- trunk/Tools/ChangeLog	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Tools/ChangeLog	2020-08-17 12:41:09 UTC (rev 265753)
@@ -1,3 +1,16 @@
+2020-08-17  Carlos Garcia Campos  <[email protected]>
+
+        [GTK][WPE] Remove support for NPAPI plugins
+        https://bugs.webkit.org/show_bug.cgi?id=215503
+
+        Reviewed by Darin Adler.
+
+        * PlatformGTK.cmake:
+        * TestWebKitAPI/Tests/WebKitGLib/TestWebKitSettings.cpp:
+        (testWebKitSettings):
+        * TestWebKitAPI/Tests/WebKitGLib/TestWebKitWebContext.cpp:
+        (beforeAll):
+
 2020-08-17  Youenn Fablet  <[email protected]>
 
         Update W3C test exporter to use Authorisation header instead of query parameter to validate GitHub account

Modified: trunk/Tools/PlatformGTK.cmake (265752 => 265753)


--- trunk/Tools/PlatformGTK.cmake	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Tools/PlatformGTK.cmake	2020-08-17 12:41:09 UTC (rev 265753)
@@ -5,10 +5,6 @@
     if (ENABLE_API_TESTS)
         add_subdirectory(TestWebKitAPI/glib)
     endif ()
-
-    if (ENABLE_NETSCAPE_PLUGIN_API)
-        add_subdirectory(DumpRenderTree/TestNetscapePlugIn)
-    endif ()
 endif ()
 
 if (ENABLE_MINIBROWSER)

Modified: trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestWebKitSettings.cpp (265752 => 265753)


--- trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestWebKitSettings.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestWebKitSettings.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -81,11 +81,6 @@
     webkit_settings_set_enable_frame_flattening(settings, TRUE);
     g_assert_true(webkit_settings_get_enable_frame_flattening(settings));
 
-    // Plugins are enabled by default.
-    g_assert_true(webkit_settings_get_enable_plugins(settings));
-    webkit_settings_set_enable_plugins(settings, FALSE);
-    g_assert_false(webkit_settings_get_enable_plugins(settings));
-
     // Java is enabled by default.
     g_assert_true(webkit_settings_get_enable_java(settings));
     webkit_settings_set_enable_java(settings, FALSE);

Modified: trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestWebKitWebContext.cpp (265752 => 265753)


--- trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestWebKitWebContext.cpp	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Tools/TestWebKitAPI/Tests/WebKitGLib/TestWebKitWebContext.cpp	2020-08-17 12:41:09 UTC (rev 265753)
@@ -76,84 +76,6 @@
     g_assert_true(webkit_web_context_is_ephemeral(context.get()));
 }
 
-#if ENABLE(NETSCAPE_PLUGIN_API)
-class PluginsTest: public Test {
-public:
-    MAKE_GLIB_TEST_FIXTURE(PluginsTest);
-
-    PluginsTest()
-        : m_mainLoop(g_main_loop_new(nullptr, TRUE))
-        , m_plugins(nullptr)
-    {
-        webkit_web_context_set_additional_plugins_directory(m_webContext.get(), WEBKIT_TEST_PLUGIN_DIR);
-    }
-
-    ~PluginsTest()
-    {
-        g_main_loop_unref(m_mainLoop);
-        g_list_free_full(m_plugins, g_object_unref);
-    }
-
-    static void getPluginsAsyncReadyCallback(GObject*, GAsyncResult* result, PluginsTest* test)
-    {
-        test->m_plugins = webkit_web_context_get_plugins_finish(test->m_webContext.get(), result, nullptr);
-        g_main_loop_quit(test->m_mainLoop);
-    }
-
-    GList* getPlugins()
-    {
-        g_list_free_full(m_plugins, g_object_unref);
-        webkit_web_context_get_plugins(m_webContext.get(), nullptr, reinterpret_cast<GAsyncReadyCallback>(getPluginsAsyncReadyCallback), this);
-        g_main_loop_run(m_mainLoop);
-        return m_plugins;
-    }
-
-    GMainLoop* m_mainLoop;
-    GList* m_plugins;
-};
-
-static void testWebContextGetPlugins(PluginsTest* test, gconstpointer)
-{
-    GList* plugins = test->getPlugins();
-    g_assert_nonnull(plugins);
-
-    GRefPtr<WebKitPlugin> testPlugin;
-    for (GList* item = plugins; item; item = g_list_next(item)) {
-        WebKitPlugin* plugin = WEBKIT_PLUGIN(item->data);
-        test->assertObjectIsDeletedWhenTestFinishes(G_OBJECT(plugin));
-        if (!g_strcmp0(webkit_plugin_get_name(plugin), "WebKit Test PlugIn")) {
-            testPlugin = plugin;
-            break;
-        }
-    }
-    g_assert_true(WEBKIT_IS_PLUGIN(testPlugin.get()));
-
-    char normalizedPath[PATH_MAX];
-    g_assert_nonnull(realpath(WEBKIT_TEST_PLUGIN_DIR, normalizedPath));
-    GUniquePtr<char> pluginPath(g_build_filename(normalizedPath, "libTestNetscapePlugIn.so", nullptr));
-    g_assert_cmpstr(webkit_plugin_get_path(testPlugin.get()), ==, pluginPath.get());
-    g_assert_cmpstr(webkit_plugin_get_description(testPlugin.get()), ==, "Simple Netscape® plug-in that handles test content for WebKit");
-    GList* mimeInfoList = webkit_plugin_get_mime_info_list(testPlugin.get());
-    g_assert_nonnull(mimeInfoList);
-    g_assert_cmpuint(g_list_length(mimeInfoList), ==, 2);
-
-    WebKitMimeInfo* mimeInfo = static_cast<WebKitMimeInfo*>(mimeInfoList->data);
-    g_assert_cmpstr(webkit_mime_info_get_mime_type(mimeInfo), ==, "image/png");
-    g_assert_cmpstr(webkit_mime_info_get_description(mimeInfo), ==, "png image");
-    const gchar* const* extensions = webkit_mime_info_get_extensions(mimeInfo);
-    g_assert_nonnull(extensions);
-    g_assert_cmpstr(extensions[0], ==, "png");
-
-    mimeInfoList = g_list_next(mimeInfoList);
-    mimeInfo = static_cast<WebKitMimeInfo*>(mimeInfoList->data);
-    g_assert_cmpstr(webkit_mime_info_get_mime_type(mimeInfo), ==, "application/x-webkit-test-netscape");
-    g_assert_cmpstr(webkit_mime_info_get_description(mimeInfo), ==, "test netscape content");
-    extensions = webkit_mime_info_get_extensions(mimeInfo);
-    g_assert_nonnull(extensions);
-    g_assert_cmpstr(extensions[0], ==, "testnetscape");
-}
-#endif // ENABLE(NETSCAPE_PLUGIN_API)
-
 static const char* kBarHTML = "<html><body>Bar</body></html>";
 static const char* kEchoHTMLFormat = "<html><body>%s</body></html>";
 static const char* errorDomain = "test";
@@ -834,9 +756,6 @@
 
     Test::add("WebKitWebContext", "default-context", testWebContextDefault);
     Test::add("WebKitWebContext", "ephemeral", testWebContextEphemeral);
-#if ENABLE(NETSCAPE_PLUGIN_API)
-    PluginsTest::add("WebKitWebContext", "get-plugins", testWebContextGetPlugins);
-#endif
     URISchemeTest::add("WebKitWebContext", "uri-scheme", testWebContextURIScheme);
     // FIXME: implement spellchecker in WPE.
 #if PLATFORM(GTK)
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebKit/UIProcess/API/gtk/WebKitError.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/gtk/WebKitError.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -76,12 +76,12 @@
 
 /**
  * WebKitPluginError:
  * @WEBKIT_PLUGIN_ERROR_FAILED: Generic plugin load failure
  * @WEBKIT_PLUGIN_ERROR_CANNOT_FIND_PLUGIN: Load failure due to missing plugin
  * @WEBKIT_PLUGIN_ERROR_CANNOT_LOAD_PLUGIN: Load failure due to inability to load plugin
  * @WEBKIT_PLUGIN_ERROR_JAVA_UNAVAILABLE: Load failure due to missing Java support that is required to load plugin
  * @WEBKIT_PLUGIN_ERROR_CONNECTION_CANCELLED: Load failure due to connection cancellation
  * @WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD: Load failure since plugin handles the load
  *
  * Enum values used to denote the various plugin errors.
  **/
@@ -160,7 +160,7 @@
 WEBKIT_API GQuark
 webkit_policy_error_quark              (void);
 
-WEBKIT_API GQuark
+WEBKIT_DEPRECATED GQuark
 webkit_plugin_error_quark              (void);
 
 WEBKIT_API GQuark
@@ -76,12 +76,12 @@
 /**
  * WebKitPluginError:
- * @WEBKIT_PLUGIN_ERROR_FAILED: Generic plugin load failure
- * @WEBKIT_PLUGIN_ERROR_CANNOT_FIND_PLUGIN: Load failure due to missing plugin
- * @WEBKIT_PLUGIN_ERROR_CANNOT_LOAD_PLUGIN: Load failure due to inability to load plugin
- * @WEBKIT_PLUGIN_ERROR_JAVA_UNAVAILABLE: Load failure due to missing Java support that is required to load plugin
- * @WEBKIT_PLUGIN_ERROR_CONNECTION_CANCELLED: Load failure due to connection cancellation
- * @WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD: Load failure since plugin handles the load
+ * @WEBKIT_PLUGIN_ERROR_FAILED: Generic plugin load failure. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_CANNOT_FIND_PLUGIN: Load failure due to missing plugin. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_CANNOT_LOAD_PLUGIN: Load failure due to inability to load plugin. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_JAVA_UNAVAILABLE: Load failure due to missing Java support that is required to load plugin. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_CONNECTION_CANCELLED: Load failure due to connection cancellation. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD: Load failure since plugin handles the load. Deprecated 2.32
  *
  * Enum values used to denote the various plugin errors.

Modified: trunk/Source/WebKit/UIProcess/API/gtk/WebKitMimeInfo.h (265752 => 265753)


--- trunk/Source/WebKit/UIProcess/API/wpe/WebKitError.h	2020-08-17 12:21:15 UTC (rev 265752)
+++ trunk/Source/WebKit/UIProcess/API/wpe/WebKitError.h	2020-08-17 12:41:09 UTC (rev 265753)
@@ -75,12 +75,12 @@
 
 /**
  * WebKitPluginError:
  * @WEBKIT_PLUGIN_ERROR_FAILED: Generic plugin load failure
  * @WEBKIT_PLUGIN_ERROR_CANNOT_FIND_PLUGIN: Load failure due to missing plugin
  * @WEBKIT_PLUGIN_ERROR_CANNOT_LOAD_PLUGIN: Load failure due to inability to load plugin
  * @WEBKIT_PLUGIN_ERROR_JAVA_UNAVAILABLE: Load failure due to missing Java support that is required to load plugin
  * @WEBKIT_PLUGIN_ERROR_CONNECTION_CANCELLED: Load failure due to connection cancellation
  * @WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD: Load failure since plugin handles the load
  *
  * Enum values used to denote the various plugin errors.
  **/
@@ -145,7 +145,7 @@
 WEBKIT_API GQuark
 webkit_policy_error_quark              (void);
 
-WEBKIT_API GQuark
+WEBKIT_DEPRECATED GQuark
 webkit_plugin_error_quark              (void);
 
 WEBKIT_API GQuark
@@ -75,12 +75,12 @@
 /**
  * WebKitPluginError:
- * @WEBKIT_PLUGIN_ERROR_FAILED: Generic plugin load failure
- * @WEBKIT_PLUGIN_ERROR_CANNOT_FIND_PLUGIN: Load failure due to missing plugin
- * @WEBKIT_PLUGIN_ERROR_CANNOT_LOAD_PLUGIN: Load failure due to inability to load plugin
- * @WEBKIT_PLUGIN_ERROR_JAVA_UNAVAILABLE: Load failure due to missing Java support that is required to load plugin
- * @WEBKIT_PLUGIN_ERROR_CONNECTION_CANCELLED: Load failure due to connection cancellation
- * @WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD: Load failure since plugin handles the load
+ * @WEBKIT_PLUGIN_ERROR_FAILED: Generic plugin load failure. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_CANNOT_FIND_PLUGIN: Load failure due to missing plugin. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_CANNOT_LOAD_PLUGIN: Load failure due to inability to load plugin. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_JAVA_UNAVAILABLE: Load failure due to missing Java support that is required to load plugin. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_CONNECTION_CANCELLED: Load failure due to connection cancellation. Deprecated 2.32
+ * @WEBKIT_PLUGIN_ERROR_WILL_HANDLE_LOAD: Load failure since plugin handles the load. Deprecated 2.32
  *
  * Enum values used to denote the various plugin errors.

Modified: trunk/Source/WebKit/UIProcess/API/wpe/WebKitMimeInfo.h (265752 => 265753)

